==> zio-aws-cognitoidentityprovider_2.12-5.17.122.1-sources.jar: zio/aws/cognitoidentityprovider/model/UpdateResourceServerRequest.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.{
  ResourceServerNameType,
  ResourceServerIdentifierType,
  UserPoolIdType
}
import scala.jdk.CollectionConverters._
final case class UpdateResourceServerRequest(
    userPoolId: UserPoolIdType,
    identifier: ResourceServerIdentifierType,
    name: ResourceServerNameType,
    scopes: Option[
      Iterable[zio.aws.cognitoidentityprovider.model.ResourceServerScopeType]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest = {
    import UpdateResourceServerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
      .builder()
      .userPoolId(UserPoolIdType.unwrap(userPoolId): java.lang.String)
      .identifier(
        ResourceServerIdentifierType.unwrap(identifier): java.lang.String
      )
      .name(ResourceServerNameType.unwrap(name): java.lang.String)
      .optionallyWith(
        scopes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.scopes)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly =
    zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest
      .wrap(buildAwsValue())
}
object UpdateResourceServerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest =
      zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest(
        userPoolId,
        identifier,
        name,
        scopes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def userPoolId: UserPoolIdType
    def identifier: ResourceServerIdentifierType
    def name: ResourceServerNameType
    def scopes: Option[List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]]
    def getUserPoolId: ZIO[Any, Nothing, UserPoolIdType] =
      ZIO.succeed(userPoolId)
    def getIdentifier: ZIO[Any, Nothing, ResourceServerIdentifierType] =
      ZIO.succeed(identifier)
    def getName: ZIO[Any, Nothing, ResourceServerNameType] = ZIO.succeed(name)
    def getScopes: ZIO[Any, AwsError, List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]] = AwsError.unwrapOptionField("scopes", scopes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ) extends zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly {
    override val userPoolId: UserPoolIdType =
      zio.aws.cognitoidentityprovider.model.primitives
        .UserPoolIdType(impl.userPoolId())
    override val identifier: ResourceServerIdentifierType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ResourceServerIdentifierType(impl.identifier())
    override val name: ResourceServerNameType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ResourceServerNameType(impl.name())
    override val scopes: Option[List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]] = scala
      .Option(impl.scopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitoidentityprovider.model.ResourceServerScopeType
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ): zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.295.11-sources.jar: zio/aws/cognitoidentityprovider/model/UpdateResourceServerRequest.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.cognitoidentityprovider.model.primitives.{
  ResourceServerNameType,
  ResourceServerIdentifierType,
  UserPoolIdType
}
import scala.jdk.CollectionConverters._
final case class UpdateResourceServerRequest(
    userPoolId: UserPoolIdType,
    identifier: ResourceServerIdentifierType,
    name: ResourceServerNameType,
    scopes: Optional[
      Iterable[zio.aws.cognitoidentityprovider.model.ResourceServerScopeType]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest = {
    import UpdateResourceServerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
      .builder()
      .userPoolId(UserPoolIdType.unwrap(userPoolId): java.lang.String)
      .identifier(
        ResourceServerIdentifierType.unwrap(identifier): java.lang.String
      )
      .name(ResourceServerNameType.unwrap(name): java.lang.String)
      .optionallyWith(
        scopes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.scopes)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly =
    zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest
      .wrap(buildAwsValue())
}
object UpdateResourceServerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest =
      zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest(
        userPoolId,
        identifier,
        name,
        scopes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def userPoolId: UserPoolIdType
    def identifier: ResourceServerIdentifierType
    def name: ResourceServerNameType
    def scopes: Optional[List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]]
    def getUserPoolId: ZIO[Any, Nothing, UserPoolIdType] =
      ZIO.succeed(userPoolId)
    def getIdentifier: ZIO[Any, Nothing, ResourceServerIdentifierType] =
      ZIO.succeed(identifier)
    def getName: ZIO[Any, Nothing, ResourceServerNameType] = ZIO.succeed(name)
    def getScopes: ZIO[Any, AwsError, List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]] = AwsError.unwrapOptionField("scopes", scopes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ) extends zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly {
    override val userPoolId: UserPoolIdType =
      zio.aws.cognitoidentityprovider.model.primitives
        .UserPoolIdType(impl.userPoolId())
    override val identifier: ResourceServerIdentifierType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ResourceServerIdentifierType(impl.identifier())
    override val name: ResourceServerNameType =
      zio.aws.cognitoidentityprovider.model.primitives
        .ResourceServerNameType(impl.name())
    override val scopes: Optional[List[
      zio.aws.cognitoidentityprovider.model.ResourceServerScopeType.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.scopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitoidentityprovider.model.ResourceServerScopeType
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.UpdateResourceServerRequest
  ): zio.aws.cognitoidentityprovider.model.UpdateResourceServerRequest.ReadOnly =
    new Wrapper(impl)
}
